.. index:: dftbutils

.. _skpar.dftbutils:

dftbutils sub-package
=====================================================

Run BS (skpar.dftbutils.runBS)
-------------------------------

.. automodule:: skpar.dftbutils.runBS
    :members:
    :undoc-members:
..    :show-inheritance:

Query DFTB (skpar.dftbutils.queryDFTB)
------------------------------------------

.. automodule:: skpar.dftbutils.queryDFTB
    :members:
    :undoc-members:
..    :show-inheritance:

Query k-Lines (skpar.dftbutils.querykLines)
--------------------------------------------

.. automodule:: skpar.dftbutils.querykLines
    :members:
    :undoc-members:
..    :show-inheritance:

Lattice (skpar.dftbutils.lattice)
---------------------------------------

.. automodule:: skpar.dftbutils.lattice
    :members:
    :undoc-members:
..    :show-inheritance:

Plot (skpar.dftbutils.plot)
-----------------------------

.. automodule:: skpar.dftbutils.plot
    :members:
    :undoc-members:
..    :show-inheritance:

Unils (skpar.dftbutils.utils)
-------------------------------

.. automodule:: skpar.dftbutils.utils
    :members:
    :undoc-members:
..    :show-inheritance:
